package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// QualificationInfo
// @Summary    	基本信息
// @Tags         资质认证------嘉俊
// @Description  资质认证-基本信息
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}		   "具体看返回内容"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/qualification/info [GET]
func QualificationInfo(c *gin.Context) {
	svc.QualificationInfo(c)
}

// QualificationSelectBase
// @Summary    	认证下拉框选择内容
// @Tags         资质认证------嘉俊
// @Description  资质认证-认证下拉框选择内容
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}		   "具体看返回内容"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/qualification/select/base [GET]
func QualificationSelectBase(c *gin.Context) {
	svc.QualificationSelectBase(c)
}

// QualificationEnterpriseSave
// @Summary    	 企业认证保存
// @Tags         资质认证------嘉俊
// @Description  资质认证-企业认证保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.AgentList   true   "请求参数"
// @Success      200   {string}		     "具体看返回内容"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/qualification/enterprise/save [POST]
func QualificationEnterpriseSave(c *gin.Context) {
	var req md.AgentList
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.QualificationEnterpriseSave(c, req)
	if err != nil {
		e.OutErr(c, 400, err)
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

// QualificationBankSave
// @Summary    	 银行资质保存
// @Tags         资质认证------嘉俊
// @Description  资质认证-银行资质保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.AgentBankInfo   true   "请求参数"
// @Success      200   {string}		     "具体看返回内容"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/qualification/bank/save [POST]
func QualificationBankSave(c *gin.Context) {
	var req md.AgentBankInfo
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.QualificationBankSave(c, req)
	if err != nil {
		e.OutErr(c, 400, err)
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

// QualificationContactSave
// @Summary    	 联系方式保存
// @Tags         资质认证------嘉俊
// @Description  资质认证-联系方式保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.AgentContactInfo   true   "请求参数"
// @Success      200   {string}		     "具体看返回内容"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/qualification/contact/save [POST]
func QualificationContactSave(c *gin.Context) {
	var req md.AgentContactInfo
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.QualificationContactSave(c, req)
	if err != nil {
		e.OutErr(c, 400, err)
		return
	}
	e.OutSuc(c, "success", nil)
	return
}
